@@ -18,13 +18,13 @@ BitcoinQuery: Query Bitcoin Core Data Files As A Database.
       run Bitcoin Core or `bitcoind` with flag `--txindex=1`,
       or rerun Bitcoin Core with `--reindex --txindex=1`.
     - After having the Bitcoin blockchain data, shutdown Bitcoin Core
-      or `bitcoind`. This program cannot run concurrent with another
-      process that is using the bitcoin blockchain data files.
+      or `bitcoind`. This program cannot run concurrently with
+      Bitcoin Core.
     - Open `python`, import the package, and instantiate `BitcoinDB`.
 
 """
 import logging as _log
-from typing import Iterator
+from typing import Iterator, List
 
 from .bitcoinquery import BitcoinDB as _BitcoinDB
 from pathlib import Path
@@ -89,7 +89,7 @@ class BitcoinDB:
         self.db = _BitcoinDB(str(path), tx_index)
         self.tx_index = tx_index
 
-    def get_max_height(self):
+    def get_max_height(self) -> int:
         """Get the maximum height found in block index.
 
         Notes:
@@ -110,7 +110,7 @@ class BitcoinDB:
 
     def get_block(self, height: int,
                   simplify: bool = True,
-                  connected: bool = False):
+                  connected: bool = False) -> dict:
         """Get the block of a specific height.
 
         Notes:
@@ -152,7 +152,7 @@ class BitcoinDB:
             else:
                 return self.db.get_block_full_connected(height)
 
-    def get_block_header(self, height: int):
+    def get_block_header(self, height: int) -> dict:
         """Get block header information.
 
         Notes:
@@ -170,7 +170,7 @@ class BitcoinDB:
         """
         return self.db.get_block_header(height)
 
-    def get_hash_from_height(self, height: int):
+    def get_hash_from_height(self, height: int) -> str:
         """Get block hash of a certain height.
 
         Notes:
@@ -184,7 +184,7 @@ class BitcoinDB:
         """
         return self.db.get_hash_from_height(height)
 
-    def get_height_from_hash(self, block_hash: str):
+    def get_height_from_hash(self, block_hash: str) -> int:
         """Get block height of certain hash.
 
         Notes:
@@ -201,7 +201,7 @@ class BitcoinDB:
     def get_transaction(self,
                         txid: str,
                         simplify: bool = True,
-                        connected: bool = False) -> list:
+                        connected: bool = False) -> dict:
         """Get transaction data from transaction ID.
 
         Notes:
@@ -215,7 +215,7 @@ class BitcoinDB:
             connected (bool): whether to replace inputs by
                 related outputs according to input outpoints.
 
-        Returns: transaction data (list).
+        Returns: transaction data.
 
         """
         if not self.tx_index:
@@ -233,7 +233,7 @@ class BitcoinDB:
             else:
                 return self.db.get_transaction_full_connected(txid)
 
-    def get_height_from_txid(self, txid: str):
+    def get_height_from_txid(self, txid: str) -> int:
         """Get height of the block that includes a transaction.
 
         Notes:
@@ -250,8 +250,8 @@ class BitcoinDB:
             raise Exception("tx_index is set to False")
         return self.db.get_height_from_txid(txid)
 
-    def get_block_batch(self, heights: list[int],
-                        simplify: bool = True) -> list[str]:
+    def get_block_batch(self, heights: List[int],
+                        simplify: bool = True) -> List[str]:
         """Get a list of blocks in batch.
 
         Notes:
@@ -309,9 +309,11 @@ class BitcoinDB:
                              stop,
                              start: int = 0,
                              simplify: bool = True,
-                             connected: bool = False) -> Iterator:
+                             connected: bool = False) -> Iterator[dict]:
         """Iterate through blocks in ascending order of heights.
 
+        This iterator fails fast. Any error interrupts it.
+
         Notes:
             This is best way to retrieve a large number of input
             addresses (set connected to `True`).
@@ -349,30 +351,7 @@ class BitcoinDB:
             else:
                 return self.db.iter_block_full_connected(stop)
 
-    def get_block_iter_array(self, heights: list[int],
-                             simplify: bool = True) -> Iterator:
-        """Iterate through blocks in any order of heights.
-
-        Notes:
-            Since this is not in sequential order, connecting inputs to
-            previous outputs is not implemented.
-
-            The performance of the iterator is similar to calling
-            `get_block(height)` in a python for loop.
-
-        Args:
-            heights: list of heights.
-            simplify: whether to use simpler format (a lot faster).
-
-        Returns: python iterator of block.
-
-        """
-        if simplify:
-            return self.db.iter_block_simple_array(heights)
-        else:
-            return self.db.iter_block_full_array(heights)
-
-    def parse_script(self, script_pub_key: str):
+    def parse_script(self, script_pub_key: str) -> dict:
         """Decode the script type and addresses from script public key.
 
         Args:
