@@ -1,4 +1,4 @@
-use super::iter::*;
+use super::par_iter::*;
 use crate::bitcoinparser::blk_file::BlkFile;
 use crate::bitcoinparser::block_index::{BlockIndex, BlockIndexRecord};
 use crate::bitcoinparser::errors::{OpError, OpResult};
@@ -151,27 +151,27 @@ impl BitcoinDB {
         Ok(tx_parsed)
     }
 
-    pub fn get_block_full_iter_seq(&self, start: u32, end: u32) -> OpResult<FBlockIteratorSequential> {
+    pub fn get_block_full_iter_seq(
+        &self,
+        start: u32,
+        end: u32,
+    ) -> OpResult<FBlockIteratorSequential> {
         FBlockIteratorSequential::new(self, start, end)
     }
 
-    pub fn get_block_simple_iter_seq(&self, start: u32, end: u32) -> OpResult<SBlockIteratorSequential> {
+    pub fn get_block_simple_iter_seq(
+        &self,
+        start: u32,
+        end: u32,
+    ) -> OpResult<SBlockIteratorSequential> {
         SBlockIteratorSequential::new(self, start, end)
     }
 
-    pub fn get_block_full_iter_arr(&self, heights: Vec<u32>) -> FBlockIteratorArray {
-        FBlockIteratorArray::new(self, heights)
-    }
-
-    pub fn get_block_simple_iter_arr(&self, heights: Vec<u32>) -> SBlockIteratorArray {
-        SBlockIteratorArray::new(self, heights)
-    }
-
-    pub fn get_block_full_connected_iter(&self, end: u32) -> OpResult<FConnectedBlockIterator> {
+    pub fn get_block_full_connected_iter(&self, end: u32) -> FConnectedBlockIterator {
         FConnectedBlockIterator::new(self, end)
     }
 
-    pub fn get_block_simple_connected_iter(&self, end: u32) -> OpResult<SConnectedBlockIterator> {
+    pub fn get_block_simple_connected_iter(&self, end: u32) -> SConnectedBlockIterator {
         SConnectedBlockIterator::new(self, end)
     }
 }
